@@ -6,7 +6,9 @@ package Net::Hotline::Constants;
 
 use strict;
 
-use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS %HTLC_COLORS);
+use vars qw(@ISA @EXPORT_OK %EXPORT_TAGS $VERSION %HTLC_COLORS);
+
+$VERSION = '0.64';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -27,17 +29,17 @@ HTLC_HDR_PCHAT_INVITE HTLC_HDR_PCHAT_SUBJECT HTLC_HDR_USER_CHANGE
 HTLC_HDR_USER_CREATE HTLC_HDR_USER_GETINFO HTLC_HDR_USER_GETLIST
 HTLC_HDR_USER_KICK HTLC_HDR_USER_OPEN HTLC_INFO_FALIAS_TYPE
 HTLC_INFO_FOLDER_TYPE HTLC_MACOS_TO_UNIX_TIME HTLC_MAGIC HTLC_MAGIC_LEN
-HTLC_MAX_PATHLEN HTLC_NEWLINE HTLC_TASK_FILE_DELETE HTLC_TASK_FILE_GET
-HTLC_TASK_FILE_INFO HTLC_TASK_FILE_LIST HTLC_TASK_FILE_MKDIR
-HTLC_TASK_FILE_MOVE HTLC_TASK_FILE_PUT HTLC_TASK_KICK HTLC_TASK_LOGIN
-HTLC_TASK_NEWS HTLC_TASK_NEWS_POST HTLC_TASK_SEND_MSG HTLC_TASK_SET_INFO
-HTLC_TASK_USER_INFO HTLC_TASK_USER_LIST HTLC_UNIX_TO_MACOS_TIME
-HTLS_DATA_AGREEMENT HTLS_DATA_CHAT HTLS_DATA_COLOR HTLS_DATA_FILE_COMMENT
-HTLS_DATA_FILE_CREATOR HTLS_DATA_FILE_CTIME HTLS_DATA_FILE_ICON
-HTLS_DATA_FILE_LIST HTLS_DATA_FILE_MTIME HTLS_DATA_FILE_NAME
-HTLS_DATA_FILE_SIZE HTLS_DATA_FILE_TYPE HTLS_DATA_HTXF_REF
-HTLS_DATA_HTXF_SIZE HTLS_DATA_ICON HTLS_DATA_MSG HTLS_DATA_NEWS
-HTLS_DATA_NEWS_POST HTLS_DATA_NICKNAME HTLS_DATA_PCHAT_REF
+HTLC_MAX_PATHLEN HTLC_NEWLINE HTLC_PATH_SEPARATOR HTLC_TASK_FILE_DELETE
+HTLC_TASK_FILE_GET HTLC_TASK_FILE_INFO HTLC_TASK_FILE_LIST
+HTLC_TASK_FILE_MKDIR HTLC_TASK_FILE_MOVE HTLC_TASK_FILE_PUT HTLC_TASK_KICK
+HTLC_TASK_LOGIN HTLC_TASK_NEWS HTLC_TASK_NEWS_POST HTLC_TASK_SEND_MSG
+HTLC_TASK_SET_INFO HTLC_TASK_USER_INFO HTLC_TASK_USER_LIST
+HTLC_UNIX_TO_MACOS_TIME HTLS_DATA_AGREEMENT HTLS_DATA_CHAT HTLS_DATA_COLOR
+HTLS_DATA_FILE_COMMENT HTLS_DATA_FILE_CREATOR HTLS_DATA_FILE_CTIME
+HTLS_DATA_FILE_ICON HTLS_DATA_FILE_LIST HTLS_DATA_FILE_MTIME
+HTLS_DATA_FILE_NAME HTLS_DATA_FILE_SIZE HTLS_DATA_FILE_TYPE
+HTLS_DATA_HTXF_REF HTLS_DATA_HTXF_SIZE HTLS_DATA_ICON HTLS_DATA_MSG
+HTLS_DATA_NEWS HTLS_DATA_NEWS_POST HTLS_DATA_NICKNAME HTLS_DATA_PCHAT_REF
 HTLS_DATA_PCHAT_SUBJECT HTLS_DATA_SERVER_MSG HTLS_DATA_SOCKET
 HTLS_DATA_TASK_ERROR HTLS_DATA_USER_INFO HTLS_DATA_USER_LIST
 HTLS_HDR_AGREEMENT HTLS_HDR_CHAT HTLS_HDR_MSG HTLS_HDR_NEWS_POST
@@ -54,8 +56,6 @@ SIZEOF_HL_TASK_FILLER SIZEOF_HL_USER_LIST_HDR);
 
 %EXPORT_TAGS = ('all' => \@EXPORT_OK);
 
-$Net::Hotline::Constants::VERSION = '0.62';
-
 use constant PATH_SEPARATOR => ($^O eq 'MacOS') ? ':' : '/';
 
 %HTLC_COLORS = (0 => 'gray',
@@ -70,6 +70,8 @@ use constant HTLC_MACOS_TO_UNIX_TIME => -2082830400;
 # Add this constant to Unix times to get Hotline (Mac OS) times
 use constant HTLC_UNIX_TO_MACOS_TIME =>  2082830400;
 
+use constant HTLC_PATH_SEPARATOR   => ':';
+
 use constant HTLC_FOLDER_TYPE      => 'fldr';
 use constant HTXF_PARTIAL_TYPE     => 'HTft';
 use constant HTXF_PARTIAL_CREATOR  => 'HTLC';
